// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-apis
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/

var _ = require('lodash');
var logger = require('apiconnect-cli-logger');
var ApicCliUtil = require('apiconnect-cli-util');

var providerOrgName = ApicCliUtil.Util.providerOrgName;
var catalogName = ApicCliUtil.Util.catalogName;

function ApimAPIsGetFormatter() {}

ApimAPIsGetFormatter.prototype.format = function(apis) {
  _.keys(apis).forEach(function(key) {
    var catalogId = key;
    apis[key].api.forEach(function(api) {
      //var apiId = api.id; // To do: Defect in the backend, only works with name:version and not id.
      var apiId = api.name + ':' + api.version;

      var apiRelProds = apis[catalogId].relatedProducts[apiId];

      logger.writeln('name: ' + api.name);
      logger.writeln('version: ' + api.version);
      logger.writeln('title: ' + api.displayName);
      logger.writeln('basepath: ' + api.basePath);

      if (api.state === 'running') {
        logger.writeln('status: online');
      } else if (api.state === 'stopped') {
        logger.writeln('status: offline');
      } else if (api.state === 'suspended') {
        logger.writeln('status: offline');
      } else {
        logger.writeln('status: ' + api.state);
      }

      logger.writeln('url: ' + api.apiPath);

      var relatedProducts = '';
      for (var i = 0; i < apiRelProds.length; i++) {
        if (i > 0) {
          relatedProducts = relatedProducts + ' ';
        }
        relatedProducts = relatedProducts + apiRelProds[i].name + ':' + apiRelProds[i].version;
      }
      logger.writeln('products: ' + relatedProducts);

      logger.writeln('catalog: ' + catalogName());
      logger.writeln('organization: ' + providerOrgName());
    });
  });
};

ApimAPIsGetFormatter.prototype.error = function(error) {
  logger.error(error);
  //throw error;
};

module.exports = ApimAPIsGetFormatter;
