#!/usr/bin/env node
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-apis
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/

var fs = require('fs');
var path = require('path');

module.exports = {
  name: 'apis',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: getTopics,
};

function helpInfo(helpFile) {
  return fs.readFileSync(path.join(__dirname, '..', 'intl', 'en', helpFile),
      'utf-8');
}

function getTopics() {
  return [ {
    name: 'apis',
    commands: [
      {
        command: 'clone',
        loginRequired: true,
        helpInfo: helpInfo('apic_apis_clone_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').apisClone(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'get <apiName[:version]>',
        loginRequired: true,
        helpInfo: helpInfo('apic_apis_get_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisGet(apiNameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'list',
        aliases: [ 'apis' ],
        loginRequired: true,
        helpInfo: helpInfo('apic_apis_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').apisList(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs' },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs' },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
          { name: 'all-catalogs', rune: 'C', type: 'boolean' },
          { name: 'all-organizations', rune: 'O', type: 'boolean' },
        ],
      },
      {
        command: 'pull <apiName[:version]>',
        loginRequired: true,
        helpInfo: helpInfo('apic_apis_pull_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisPull(apiNameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'set <apiName[:version]>',
        loginRequired: true,
        helpInfo: helpInfo('apic_apis_set_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisSet(apiNameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.hostname', required: true },
          { name: 'status', type: 'enum', values: [ 'online', 'offline' ] },
        ],
      },
    ],
  } ];
};
