#!/usr/bin/env node
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-apis
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/

var ApicCliUtil = require('apiconnect-cli-util');
var ApimApisCloneFormatter = require('./formatter/apis_clone_formatter');
var ApimApisGetFormatter = require('./formatter/apis_get_formatter');
var ApimApisListFormatter = require('./formatter/apis_list_formatter');
var ApimApisPullFormatter = require('./formatter/apis_pull_formatter');
var ApimApisSetFormatter = require('./formatter/apis_set_formatter');
var APIs = require('./apis');
var Promise = require('bluebird');
var SharedCtx = require('./util/shared_ctx');

var checkForOrgOrAllOrgAndCatalogOrCatalog = ApicCliUtil.Util.checkForOrgOrAllOrgAndCatalogOrCatalog;
var checkForOrgOrCatalog = ApicCliUtil.Util.checkForOrgOrCatalog;
var context = ApicCliUtil.Context;

Promise.promisifyAll(APIs.prototype);

exports.apisClone = function(options) {
  checkForOrgOrCatalog(options);
  context.set(
    {
      server: options.server,
      organization: options.organization,
      catalog: options.catalog,
    });

  var a = new APIs();
  var fmt = new ApimApisCloneFormatter();

  SharedCtx.organization = options.organization;
  SharedCtx.catalogName = options.catalog;
  SharedCtx.productOnly = options.productOnly;

  var opts = {
    catalog: options.catalog,
    organization: options.organization,
  };

  return a.cloneAPIAsync(opts).then(function(result) {
    fmt.format(result);
  });
};

exports.apisGet = function apisGet(apiVersion, options) {
  options.apiVersion = apiVersion;

  checkForOrgOrCatalog(options);
  context.set(
    {
      server: options.server,
      organization: options.organization,
      catalog: options.catalog,
    });

  var a = new APIs();
  var fmt = new ApimApisGetFormatter();

  var opts = {
    catalog: options.catalog,
    organization: options.organization,
  };

  return a.getAPIAsync(opts, apiVersion).then(function(result) {
    fmt.format(result);
  });
};

exports.apisList = function apisList(options) {
  checkForOrgOrAllOrgAndCatalogOrCatalog(options);
  context.set(
    {
      server: options.server,
      organization: options.organization,
      catalog: options.catalog,
    });

  var a = new APIs();
  var fmt = new ApimApisListFormatter();

  var opts = {
    allOrganizations: options.allOrganizations,
    allCatalogs: options.allCatalogs,
    catalog: options.catalog,
    organization: options.organization,
  };

  return a.listAPIsAsync(opts).then(function(result) {
    fmt.format(result);
  });
};

exports.apisPull = function apisPull(apiVersion, options) {
  options.apiVersion = apiVersion;

  checkForOrgOrCatalog(options);
  context.set(
    {
      server: options.server,
      organization: options.organization,
      catalog: options.catalog,
    });

  var a = new APIs();
  var fmt = new ApimApisPullFormatter();

  var opts = {
    catalog: options.catalog,
    organization: options.organization,
  };

  return a.pullAPIAsync(opts, options.apiVersion).then(function(result) {
    fmt.format(result);
  });
};

exports.apisSet = function apisSet(apiVersion, options) {
  options.apiVersion = apiVersion;

  checkForOrgOrCatalog(options);
  context.set(
    {
      server: options.server,
      organization: options.organization,
      catalog: options.catalog,
    });

  if (options.status) {
    if ((options.status !== 'online') && (options.status !== 'offline')) {
      throw new Error('The --status option is required.');
    } else if (options.status === 'online') {
      options.newStatus = 'start';
    } else if (options.status === 'offline') {
      options.newStatus = 'stop';
    }
  }

  var a = new APIs();
  var fmt = new ApimApisSetFormatter();

  var opts = {
    catalog: options.catalog,
    organization: options.organization,
  };

  return a.setAPIAsync(opts, options.apiVersion, options.newStatus).then(function(api) {
    fmt.format(api, options.status);
  });
};
